# pdf-bookmark-manager
A simple GTK+3 PDF bookmark (table of contents) manager, with optional zathura integration.

## Dependencies
 - Python 3
 - pdftk
 - GTK+3
 - PyGObject
 - dbus-python (for integrating with zathura)
 - zathura

*IMPORTANT: Note that pdftk, GTK+3 and zathura will not be installed from PyPI,
as they are not Python packages.*
 
